#include <stdio.h>
#include <stdlib.h>
#include <roxml.h>
#include "classe.h"

/*!
* \file classe.c
* \brief Fichier contenant le code des fonctions liees aux classes.
*/


Classe* Librairie_Classes(char *filename){

return Remplir_Classes_log(filename);

}


/*!
 * \fn Classe* Remplir_Classes_log(char *filename)
 * \brief La fonction remplit un tableau de classes a partir d'un fichier xml.
 *
 * \param Le nom du fichier a lire.
 * \return Un tableau de classes.
 */
Classe* Remplir_Classes_log(char *filename)
{
    int ret = 0;

    FILE* Classes_log = NULL;
    Classes_log = fopen("Classes_XML_log", "w");
    if (Classes_log != NULL)
    {
        fprintf(Classes_log,"Fichier decrivant le deroulement de la procedure d'aquisition des classes\n\n");
        ret = Remplir_Classes(Classes_log, filename);
        fclose(Classes_log);
    }
    else
    {
        fprintf(stderr,"Impossible d'ouvrir le fichier Classes_XML_log");
    }
    return ret;
}

/*!
 * \fn int getPVMax(Classe * c)
 * \brief La fonction retourne le nombre de PV maximum de la Classe.
 *
 * \param La Classe a tester
 * \return un entier representant le nombre de PV maximum de la Classe
 */
int getPVMax(Classe * c){
    return c->PV_max;
}

/*!
 * \fn int getManaMax(Classe * c)
 * \brief La fonction retourne le Mana maximum de la Classe.
 *
 * \param La Classe a tester
 * \return un entier representant le Mana maximum de la Classe
 */
int getManaMax(Classe * c){
    return c->mana_max;
}

/*!
 * \fn int getManaMax(Classe * c)
 * \brief La fonction retourne le nombre de PD maximum de la Classe.
 *
 * \param La Classe a tester
 * \return un entier representant le nombre de PD maximum de la Classe
 */
int getPDMax(Classe * c){
    return c->points_deplacement_max;
}

/*!
 * \fn int getNomClasse(Classe * c)
 * \brief La fonction retourne un pointeur vers le nom de la Classe.
 *
 * \param La Classe a tester
 * \return un Pointeur vers le nom de la Classe.
 */
char * getNomClasse(Classe * c){
    return c->nom;
}



